@@ -26,9 +26,12 @@
 struct reddit_submit_options_t
 {
   char *url;
+  char *title;
+  char *subreddit;
   struct reddit_state_t *state;
   int parsing_errors;
 };
+char * argp_parse_link (struct argp_state *state, char *link, struct reddit_state_t *r);
 
 int reddit_submit_parse_argp (struct reddit_state_t *, int argc, char **argv, struct argp *);
 int reddit_submit (struct reddit_state_t *, struct reddit_submit_options_t *);
